import type { RouteRecordRaw } from "vue-router";
import Middleware from "@/js/contexts/shared/models/Middleware";
import { Permission } from "@/js/contexts/shared/models/Permission";

const routes: RouteRecordRaw[] = [
  {
    name: "admin.settings",
    path: "/admin/settings",
    meta: {
      middleware: [Middleware.auth],
      permissions: [
        Permission.ADMIN_SETTINGS_GENERAL,
        Permission.ADMIN_SETTINGS_LINKS,
        Permission.ADMIN_SETTINGS_LANDING,
        Permission.ADMIN_SETTINGS_SEO,
        Permission.ADMIN_SETTINGS_APPEARANCE,
        Permission.ADMIN_SETTINGS_AUTHENTICATION,
        Permission.ADMIN_SETTINGS_OUTGOING_MAIL,
      ],
    },
    redirect: () => ({ name: "admin.settings.general" }),
    children: [
      {
        name: "admin.settings.general",
        path: "/admin/settings/general",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsGeneralPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_GENERAL],
        },
      },
      {
        name: "admin.settings.links",
        path: "/admin/settings/links",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsLinksPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_LINKS],
        },
      },
      {
        name: "admin.settings.landing",
        path: "/admin/settings/landing",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsLandingPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_LANDING],
        },
      },
      {
        name: "admin.settings.seo",
        path: "/admin/settings/seo",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsSeoPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_SEO],
        },
      },
      {
        name: "admin.settings.appearance",
        path: "/admin/settings/appearance",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsAppearancePage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_APPEARANCE],
        },
      },
      {
        name: "admin.settings.authentication",
        path: "/admin/settings/authentication",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsAuthenticationPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_AUTHENTICATION],
        },
      },
      {
        name: "admin.settings.outgoing_mail",
        path: "/admin/settings/outgoing-mail",
        component: () => import("@/js/contexts/admin/settings/ui/pages/SettingsOutgoingMailPage.vue"),
        meta: {
          middleware: [Middleware.auth],
          permissions: [Permission.ADMIN_SETTINGS_OUTGOING_MAIL],
        },
      },
    ],
  },
];

export default routes;
